<?php

	require_once('settings.inc.php');
	
	
	$coordinatesfile2016 = dirname(__FILE__) . '/latlongs2016.csv';
	$coordinatesfile2017 = dirname(__FILE__) . '/latlongs2017.csv';

	$neighborhoodkmlfile = dirname(__FILE__) . '/nolaneighborhoods.kml';
?>
<!DOCTYPE html>
<html>
  <head>
    <title>Discharge of Firearm Heatmap</title>
    <meta name="viewport" content="initial-scale=1.0">
    <meta charset="utf-8">
    <style>
	
	  
      /* Always set the map height explicitly to define the size of the div
       * element that contains the map. */
      #map {
        height: 96%;
		z-index:50;
      }
      /* Optional: Makes the sample page fill the window. */
      html, body {
        height: 100%;
        margin: 0;
        padding: 0;
		font-family:Arial, Helvetica, sans-serif;
		font-size:.85em;
      }
	  
	  #upperright{
			position:relative;
			float: right;
			margin-bottom: 15px;
			margin-left: 15px; 
			z-index:100;
			
	  }
	  a{
		  text-decoration:none;
		  color:orange;
	  }
	  
    </style>
	
	
	
	<!-- BEGIN jQuery includes -->
	<script src="https://code.jquery.com/jquery-2.2.4.min.js" type="text/javascript"></script>
	<script  src="http://code.jquery.com/ui/1.12.0/jquery-ui.min.js" integrity="sha256-eGE6blurk5sHj+rmkfsGYeKyZx3M4bG+ZlFyA7Kns7E=" crossorigin="anonymous"></script>
	<link rel="stylesheet" media="screen" type="text/css" href="http://code.jquery.com/ui/1.12.0/themes/smoothness/jquery-ui.css" />
	


  </head>
  <body>
	
		<div id="map"></div>
		
		<div id="upperright">
			Source: <a href="https://data.nola.gov/" target="_blank">data.nola.gov</a> | 
			<a href="https://www.meetup.com/Hacks-Hackers-New-Orleans/" target="_blank">Hackathon</a> Feb 5, 2017 (<a href="download.zip" target="_blank">download</a>) | 
			red = 2017, green = 2016</div>
		<div class="clear"></div>
	</div>
	
    <script>
		var map;
		function initMap() {
			map = new google.maps.Map(document.getElementById('map'), {
				center: {
					lat: <?php echo $GLOBALS['centerlat']?>, 
					lng: <?php echo $GLOBALS['centerlng']?>
				},
				zoom: <?php echo $GLOBALS['defaultzoom']?>
			});
			
			
			
			
			var coordsets = {}
			
			//load 2016 data from file into json
			coordsets['2016'] = <?php echo json_encode(loadCoordDataFromFile($coordinatesfile2016,JSON_PRETTY_PRINT)); ?>;
			
			//load 2017 data from file into json
			 coordsets['2017'] = <?php echo json_encode(loadCoordDataFromFile($coordinatesfile2017,JSON_PRETTY_PRINT)); ?>;
			
			
			//style settings for our sets of points (using settings from https://developers.google.com/maps/documentation/javascript/examples/circle-simple)
			var markersettings = {
				'2016':{
					strokeColor: '#00FF00',	//green
					strokeOpacity: 0.8,
					strokeWeight: 0,
					fillColor: '#00FF00',
					fillOpacity: 0.35,
					map: map,
					radius: 100
					
				},
				'2017':{
					strokeColor: '#FF0000',	//red
					strokeOpacity: 0.8,
					strokeWeight: 0,
					fillColor: '#FF0000',
					fillOpacity: 0.35,
					map: map,
					radius: 100					
				},
				
			};
			
			
			//draw each set of coordinates, in their chosen style
			$.each(coordsets,function(coordsetname,latlngs){
				
				//loop over each coordinate set contained in 'coordsetvals'
				$.each(latlngs,function(blabla,latlng){
					
					//copy settings for this data set
					var dotinfo = markersettings[coordsetname];
					
					//apply these coordinates to this setting
					dotinfo['center'] = latlng;
					
					//make a circle with these settings on the map!
					new google.maps.Circle(dotinfo);
					
					
				});
				
			});
			
			
			
			//load the neighborhood boundaries
			var neighborhoods = <?php echo json_encode(loadNeighborhoodBoundaries($neighborhoodkmlfile,JSON_PRETTY_PRINT)); ?>;
			
			
			//polyline settings - https://developers.google.com/maps/documentation/javascript/examples/polyline-simple
			var polylinesettings = {
				geodesic: true,
				strokeColor: '#FF0000',
				strokeOpacity: 1.0,
				strokeWeight: 2
			};
			
			
			$.each(neighborhoods,function(index,neighborhood){
				
				var temppolylinesettings = polylinesettings;	//load line settings
				temppolylinesettings['path'] = neighborhood['coords']; //set coordinates
				
				//create line and apply to map
				var temppolyline = new google.maps.Polyline(temppolylinesettings);
				temppolyline.setMap(map);	
			});
			
			
			
			
			
			
			
		}
    </script>
    <script src="https://maps.googleapis.com/maps/api/js?key=<?php echo $GLOBALS['googleappid']; ?>&callback=initMap" async defer></script>
	
	
	
	
	
  </body>
</html>
<?php
	
	function loadCoordDataFromFile($coordinatesfile)
	{
		$finalcoords = array();
		
		//open coordinates file
		$coordsraw = file_get_contents($coordinatesfile);
		
		//explode on newline
		$coordlines = explode("\n",$coordsraw);
		
		foreach($coordlines as $coordline)
		{
			//match latlng
			//format: (30.03115205, -89.99442124)
			preg_match('/([0123456789.-]+), ([0123456789.-]+)/i',$coordline,$matches);
			
			//echo "<pre>";
			//print_R($matches);
			//echo "</pre>";
			
			if(count($matches) > 0)
			{
				$coord['lat'] = $matches[1] + 0;
				$coord['lng'] = $matches[2] + 0;
				
				$finalcoords[] = $coord;
			}
		}
	
		return $finalcoords;
	}
	
	function loadNeighborhoodBoundaries($inputfile)
	{
		//read in the entire kml file
		$filecontents = file_get_contents($inputfile);
		
		
		//find each matching set of <Placemark> tags
		preg_match_all('/<Placemark>.+<\/Placemark>/isU',$filecontents,$matches);
		
		//print_r($matches);
		
		$placemarkgroups = $matches[0];
		
		
		$neighborhoods = array();
		
		foreach($placemarkgroups as $placemarkgroup)
		{
			$neighborhood = array();
			
			//match out the name
			//<name>Lake Catherine</name>
			preg_match('/<name>(.+)<\/name>/iU',$placemarkgroup,$matches);
			
			$name = $matches[1];
			$neighborhood['name'] = $name;
			//preg_match();
			
			
			
			//match out the coordinates
			// <coordinates>-90.073965,30.000194,0.0 -90.073993,30.002061000000005,0.0 -90.070431,30.005219999999994,0.0 -90.06948700000001,30.006075,0.0 -90.07095,30.021477999999995,0.0 -90.083005,30.020976,0.0 -90.084894,30.018263999999995,0.0 -90.086181,30.011463,0.0 -90.085884,29.999395000000003,0.0 -90.073965,30.000194,0.0</coordinates>
			preg_match('/<coordinates>(.+)<\/coordinates>/iU',$placemarkgroup,$matches);
			
			$tempcoordstring = $matches[1];
			
			//split on space
			$tempcoordsplit = explode(' ',$tempcoordstring);
			
			foreach($tempcoordsplit as $tempcoord)
			{
				//split on comma
				$tempcoordparts = explode(',',$tempcoord);
				$neighborhood['coords'][] = array(
					'lat'=>$tempcoordparts[1] + 0,
					'lng'=>$tempcoordparts[0] + 0,
				);
				
			}
			
			
			
			
			//save to neighborhoods array
			$neighborhoods[$name] = $neighborhood;
			
			
		}
		
		
		//print_r($neighborhoods);
		
		
		return $neighborhoods;
	}
?>